@@ -33,9 +33,10 @@
 #  define OKTETAKASTENCORE_DEPRECATED_NO_EXPORT OKTETAKASTENCORE_NO_EXPORT OKTETAKASTENCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define OKTETAKASTENCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef OKTETAKASTENCORE_NO_DEPRECATED
+#    define OKTETAKASTENCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
